@@ -21,7 +21,6 @@ package org.apache.skywalking.banyandb.v1.client;
 import lombok.Getter;
 import org.apache.skywalking.banyandb.measure.v1.BanyandbMeasure;
 import org.apache.skywalking.banyandb.model.v1.BanyandbModel;
-import org.apache.skywalking.banyandb.v1.client.metadata.Measure;
 
 import java.util.HashMap;
 import java.util.Map;
@@ -34,16 +33,14 @@ public class DataPoint extends RowEntity {
     private final Map<String, Object> fields;
 
     public static DataPoint create(BanyandbMeasure.DataPoint dataPoint) {
-        final DataPoint dp = new DataPoint(dataPoint);
-        dp.id = dp.getTagValue(Measure.ID);
-        return dp;
+        return new DataPoint(dataPoint);
     }
 
     private DataPoint(BanyandbMeasure.DataPoint dataPoint) {
         super(dataPoint.getTimestamp(), dataPoint.getTagFamiliesList());
         this.fields = new HashMap<>(dataPoint.getFieldsCount());
         for (BanyandbMeasure.DataPoint.Field f : dataPoint.getFieldsList()) {
-            this.fields.put(f.getName(), convertToJavaType(f.getValue()));
+            this.fields.put(f.getName(), convertFileValueToJavaType(f.getValue()));
         }
     }
 
@@ -51,7 +48,7 @@ public class DataPoint extends RowEntity {
         return (T) this.fields.get(fieldName);
     }
 
-    private Object convertToJavaType(BanyandbModel.FieldValue fieldValue) {
+    static Object convertFileValueToJavaType(BanyandbModel.FieldValue fieldValue) {
         switch (fieldValue.getValueCase()) {
             case INT:
                 return fieldValue.getInt().getValue();
@@ -61,6 +58,8 @@ public class DataPoint extends RowEntity {
                 return null;
             case BINARY_DATA:
                 return fieldValue.getBinaryData().toByteArray();
+            case FLOAT:
+                return fieldValue.getFloat().getValue();
             default:
                 throw new IllegalStateException("illegal type of FieldValue");
         }
