@@ -23,7 +23,7 @@ import org.apache.skywalking.banyandb.common.v1.BanyandbCommon;
 import org.apache.skywalking.banyandb.measure.v1.BanyandbMeasure;
 import org.apache.skywalking.banyandb.model.v1.BanyandbModel;
 import org.apache.skywalking.banyandb.v1.client.grpc.exception.BanyanDBException;
-import org.apache.skywalking.banyandb.v1.client.metadata.Measure;
+import org.apache.skywalking.banyandb.v1.client.metadata.MetadataCache;
 import org.apache.skywalking.banyandb.v1.client.metadata.Serializable;
 
 import java.util.Deque;
@@ -36,8 +36,8 @@ public class MeasureWrite extends AbstractWrite<BanyandbMeasure.WriteRequest> {
      */
     private final Object[] fields;
 
-    public MeasureWrite(final String group, final String name, long timestamp) {
-        super(group, name, timestamp);
+    MeasureWrite(MetadataCache.EntityMetadata entityMetadata, long timestamp) {
+        super(entityMetadata, timestamp);
         this.fields = new Object[this.entityMetadata.getTotalFields()];
     }
 
@@ -52,17 +52,20 @@ public class MeasureWrite extends AbstractWrite<BanyandbMeasure.WriteRequest> {
         return (MeasureWrite) super.tag(tagName, tagValue);
     }
 
-    public MeasureWrite setID(String idValue) throws BanyanDBException {
-        return this.tag(Measure.ID, TagAndValue.idTagValue(idValue));
-    }
-
     /**
      * Build a write request
      *
      * @return {@link BanyandbMeasure.WriteRequest} for the bulk process.
      */
     @Override
-    protected BanyandbMeasure.WriteRequest build(BanyandbCommon.Metadata metadata, Timestamp ts) {
+    protected BanyandbMeasure.WriteRequest build(BanyandbCommon.Metadata metadata) {
+        if (!timestamp.isPresent() || timestamp.get() <= 0) {
+            throw new IllegalArgumentException("Timestamp is required and must be greater than 0 for stream writes.");
+        }
+        Timestamp ts = Timestamp.newBuilder()
+                .setSeconds(timestamp.get() / 1000)
+                .setNanos((int) (timestamp.get() % 1000 * 1_000_000)).build();
+
         final BanyandbMeasure.WriteRequest.Builder builder = BanyandbMeasure.WriteRequest.newBuilder();
         builder.setMetadata(metadata);
         final BanyandbMeasure.DataPointValue.Builder datapointValueBuilder = BanyandbMeasure.DataPointValue.newBuilder();
@@ -70,14 +73,13 @@ public class MeasureWrite extends AbstractWrite<BanyandbMeasure.WriteRequest> {
         // memorize the last offset for the last tag family
         int lastFamilyOffset = 0;
         for (final int tagsPerFamily : this.entityMetadata.getTagFamilyCapacity()) {
-            final BanyandbModel.TagFamilyForWrite.Builder b = BanyandbModel.TagFamilyForWrite.newBuilder();
             boolean firstNonNullTagFound = false;
             Deque<BanyandbModel.TagValue> tags = new LinkedList<>();
             for (int j = tagsPerFamily - 1; j >= 0; j--) {
                 Object obj = this.tags[lastFamilyOffset + j];
                 if (obj == null) {
                     if (firstNonNullTagFound) {
-                        b.addTags(TagAndValue.nullTagValue().serialize());
+                        tags.addFirst(TagAndValue.nullTagValue().serialize());
                     }
                     continue;
                 }
@@ -85,7 +87,7 @@ public class MeasureWrite extends AbstractWrite<BanyandbMeasure.WriteRequest> {
                 tags.addFirst(((Serializable<BanyandbModel.TagValue>) obj).serialize());
             }
             lastFamilyOffset += tagsPerFamily;
-            datapointValueBuilder.addTagFamilies(b.addAllTags(tags).build());
+            datapointValueBuilder.addTagFamilies(BanyandbModel.TagFamilyForWrite.newBuilder().addAllTags(tags).build());
         }
 
         for (int i = 0; i < this.entityMetadata.getTotalFields(); i++) {
@@ -98,6 +100,7 @@ public class MeasureWrite extends AbstractWrite<BanyandbMeasure.WriteRequest> {
         }
 
         builder.setDataPoint(datapointValueBuilder);
+        builder.setMessageId(System.nanoTime());
         return builder.build();
     }
 }
