@@ -26,7 +26,7 @@ import org.apache.skywalking.banyandb.v1.client.grpc.channel.ChannelManagerSetti
 /**
  * Client connection options.
  */
-@Setter
+@Setter(AccessLevel.PUBLIC)
 @Getter(AccessLevel.PUBLIC)
 public class Options {
     /**
@@ -45,10 +45,7 @@ public class Options {
      * Threshold of force gRPC reconnection if network issue is encountered
      */
     private long forceReconnectionThreshold = 1;
-    /**
-     * Threshold of resolving the DNS
-     */
-    private long resolveDNSInterval = 30 * 60;
+
     /**
      * Force use TLS for gRPC
      * Default is false
@@ -59,21 +56,31 @@ public class Options {
      */
     private String sslTrustCAPath = "";
     /**
-     * SSL: Cert Chain Path
+     * Basic Auth: username of BanyanDB server
      */
-    private String sslCertChainPath = "";
+    private String username = "";
     /**
-     * SSL: Cert Key Path
+     * Basic Auth: password of BanyanDB server
      */
-    private String sslKeyPath = "";
+    private String password = "";
+    /**
+     * Enable Prometheus metrics
+     */
+    private PrometheusMetricsOpts prometheusMetricsOpts = new PrometheusMetricsOpts();
 
-    Options() {
+    public Options() {
     }
 
     ChannelManagerSettings buildChannelManagerSettings() {
         return ChannelManagerSettings.newBuilder()
-                .setRefreshInterval(this.refreshInterval)
-                .setForceReconnectionThreshold(this.forceReconnectionThreshold)
-                .build();
+                                     .setRefreshInterval(this.refreshInterval)
+                                     .setForceReconnectionThreshold(this.forceReconnectionThreshold)
+                                     .build();
     }
-}
\ No newline at end of file
+
+    public static class PrometheusMetricsOpts {
+        @Setter(AccessLevel.PUBLIC)
+        @Getter
+        private String clientID = "default";
+    }
+}
