@@ -18,12 +18,12 @@
 
 package org.apache.skywalking.banyandb.v1.client;
 
-import java.util.ArrayList;
-import java.util.List;
-
 import lombok.Getter;
 import org.apache.skywalking.banyandb.stream.v1.BanyandbStream;
 
+import java.util.ArrayList;
+import java.util.List;
+
 /**
  * StreamQueryResponse represents the stream query result.
  */
@@ -31,10 +31,14 @@ public class StreamQueryResponse {
     @Getter
     private final List<Element> elements;
 
+    @Getter
+    private final Trace trace;
+
     StreamQueryResponse(BanyandbStream.QueryResponse response) {
         final List<BanyandbStream.Element> elementsList = response.getElementsList();
         elements = new ArrayList<>(elementsList.size());
         elementsList.forEach(element -> elements.add(Element.create(element)));
+        this.trace = Trace.convertFromProto(response.getTrace());
     }
 
     /**
