@@ -22,6 +22,7 @@ import java.util.List;
 
 import com.google.protobuf.ByteString;
 import com.google.protobuf.NullValue;
+import com.google.protobuf.Timestamp;
 import lombok.EqualsAndHashCode;
 import org.apache.skywalking.banyandb.model.v1.BanyandbModel;
 
@@ -77,6 +78,8 @@ public abstract class TagAndValue<T> extends Value<T> {
                 return new StringArrayTagPair(tag.getKey(), tag.getValue().getStrArray().getValueList());
             case BINARY_DATA:
                 return new BinaryTagPair(tag.getKey(), tag.getValue().getBinaryData());
+            case TIMESTAMP:
+                return new TimestampTagPair(tag.getKey(), tag.getValue().getTimestamp());
             case NULL:
                 return new NullTagPair(tag.getKey());
             default:
@@ -104,26 +107,6 @@ public abstract class TagAndValue<T> extends Value<T> {
         return new StringTagPair(tagName, value);
     }
 
-    @EqualsAndHashCode(callSuper = true)
-    public static class IDTagPair extends TagAndValue<String> {
-        IDTagPair(final String tagName, final String value) {
-            super(tagName, value);
-        }
-
-        @Override
-        protected BanyandbModel.TagValue buildTypedTagValue() {
-            return BanyandbModel.TagValue.newBuilder()
-                    .setId(BanyandbModel.ID
-                            .newBuilder()
-                            .setValue(value).build())
-                    .build();
-        }
-    }
-
-    public static TagAndValue<String> newIDTag(final String tagName, final String value) {
-        return new IDTagPair(tagName, value);
-    }
-
     @EqualsAndHashCode(callSuper = true)
     public static class StringArrayTagPair extends TagAndValue<List<String>> {
         StringArrayTagPair(final String tagName, final List<String> value) {
@@ -202,6 +185,32 @@ public abstract class TagAndValue<T> extends Value<T> {
         return new BinaryTagPair(tagName, ByteString.copyFrom(bytes));
     }
 
+    @EqualsAndHashCode(callSuper = true)
+    public static class TimestampTagPair extends TagAndValue<Long> {
+        TimestampTagPair(final String tagName, final long epochMilli) {
+            super(tagName, epochMilli);
+        }
+
+        TimestampTagPair(final String tagName, final Timestamp value) {
+            super(tagName, value.getSeconds() * 1000 + value.getNanos() / 1000000);
+        }
+
+        @Override
+        protected BanyandbModel.TagValue buildTypedTagValue() {
+            Timestamp timestamp = Timestamp.newBuilder()
+                    .setSeconds(value / 1000)
+                    .setNanos((int) ((value % 1000) * 1000000))
+                    .build();
+            return BanyandbModel.TagValue.newBuilder()
+                    .setTimestamp(timestamp)
+                    .build();
+        }
+    }
+
+    public static TagAndValue<Long> newTimestampTag(final String tagName, final long epochMilli) {
+        return new TimestampTagPair(tagName, epochMilli);
+    }
+
     @EqualsAndHashCode(callSuper = true)
     public static class NullTagPair extends TagAndValue<Void> {
         NullTagPair(final String tagName) {
