@@ -18,32 +18,32 @@
 
 package org.apache.skywalking.banyandb.v1.client.grpc.channel;
 
-import com.google.common.base.Strings;
 import io.grpc.ManagedChannel;
 import io.grpc.netty.GrpcSslContexts;
 import io.grpc.netty.NegotiationType;
 import io.grpc.netty.NettyChannelBuilder;
 import io.netty.handler.ssl.SslContextBuilder;
+import io.netty.util.internal.PlatformDependent;
 import lombok.RequiredArgsConstructor;
 import lombok.extern.slf4j.Slf4j;
 import org.apache.skywalking.banyandb.v1.client.Options;
-import org.apache.skywalking.banyandb.v1.client.util.PrivateKeyUtil;
 
 import java.io.File;
-import java.io.FileInputStream;
 import java.io.IOException;
-import java.io.InputStream;
+import java.net.InetSocketAddress;
+import java.net.SocketAddress;
+import java.net.URI;
+import java.net.UnknownHostException;
 
 @Slf4j
 @RequiredArgsConstructor
 public class DefaultChannelFactory implements ChannelFactory {
-    private final String host;
-    private final int port;
+    private final URI[] targets;
     private final Options options;
 
     @Override
     public ManagedChannel create() throws IOException {
-        NettyChannelBuilder managedChannelBuilder = NettyChannelBuilder.forAddress(this.host, this.port)
+        NettyChannelBuilder managedChannelBuilder = NettyChannelBuilder.forAddress(resolveAddress())
                 .maxInboundMessageSize(options.getMaxInboundMessageSize())
                 .usePlaintext();
 
@@ -53,26 +53,19 @@ public class DefaultChannelFactory implements ChannelFactory {
             SslContextBuilder builder = GrpcSslContexts.forClient();
 
             if (isCAFileExist) {
-                String certPath = options.getSslCertChainPath();
-                String keyPath = options.getSslKeyPath();
-                if (!Strings.isNullOrEmpty(certPath) && Strings.isNullOrEmpty(keyPath)) {
-                    File keyFile = new File(keyPath);
-                    File certFile = new File(certPath);
-
-                    if (certFile.isFile() && keyFile.isFile()) {
-                        try (InputStream cert = new FileInputStream(certFile);
-                             InputStream key = PrivateKeyUtil.loadDecryptionKey(keyFile.getAbsolutePath())) {
-                            builder.keyManager(cert, key);
-                        }
-                    } else if (!certFile.isFile() || !keyFile.isFile()) {
-                        log.warn("Failed to enable mTLS caused by cert or key cannot be found.");
-                    }
-                }
-
                 builder.trustManager(caFile);
             }
             managedChannelBuilder.negotiationType(NegotiationType.TLS).sslContext(builder.build());
         }
         return managedChannelBuilder.build();
     }
+
+    private SocketAddress resolveAddress() throws UnknownHostException {
+        int numAddresses = this.targets.length;
+        if (numAddresses < 1) {
+            throw new UnknownHostException();
+        }
+        int offset = numAddresses == 1 ? 0 : PlatformDependent.threadLocalRandom().nextInt(numAddresses);
+        return new InetSocketAddress(this.targets[offset].getHost(), this.targets[offset].getPort());
+    }
 }
